unit UNewGameForm;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls,
  ComCtrls, UCore;

type

  { TNewGameForm }

  TNewGameForm = class(TForm)
    ButtonStart: TButton;
    ButtonCancel: TButton;
    ColorButton1: TColorButton;
    EditUp: TEdit;
    EditDown: TEdit;
    EditLeft: TEdit;
    EditRight: TEdit;
    EditShoot: TEdit;
    EditName: TEdit;
    GroupBox1: TGroupBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    ListView1: TListView;
    procedure ColorButton1ColorChanged(Sender: TObject);
    procedure EditDownChange(Sender: TObject);
    procedure EditDownKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState
      );
    procedure EditLeftChange(Sender: TObject);
    procedure EditLeftKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState
      );
    procedure EditNameChange(Sender: TObject);
    procedure EditRightChange(Sender: TObject);
    procedure EditRightKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure EditShootChange(Sender: TObject);
    procedure EditShootKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure EditUpChange(Sender: TObject);
    procedure EditUpKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure ListView1Change(Sender: TObject; Item: TListItem;
      Change: TItemChange);
    procedure ListView1Data(Sender: TObject; Item: TListItem);
    procedure ListView1SelectItem(Sender: TObject; Item: TListItem;
      Selected: Boolean);
  private
    Players: TPlayers;
    procedure ReloadList;
  public
    procedure LoadData(Engine: TEngine);
    procedure SaveData(Engine: TEngine);
  end; 

var
  NewGameForm: TNewGameForm;

implementation

uses
  UMainForm;

{$R *.lfm}

{ TNewGameForm }

procedure TNewGameForm.ListView1Change(Sender: TObject; Item: TListItem;
  Change: TItemChange);
begin
  if Change = ctState then
    TPlayer(Item.Data).Enabled := Item.Checked;
end;

procedure TNewGameForm.ListView1Data(Sender: TObject; Item: TListItem);
begin
  if Item.Index < Players.Count then
  with TPlayer(Players[Item.Index]) do begin
    Item.Caption := Name;
    Item.SubItems.Add(IntToHex(Color, 6));
    Item.SubItems.Add('');
    Item.Checked := Enabled;
    Item.Data := Pointer(Players[Item.Index]);
  end;
end;

procedure TNewGameForm.ListView1SelectItem(Sender: TObject; Item: TListItem;
  Selected: Boolean);
begin
  if Assigned(Item) and Selected then
  with TPlayer(Item.Data) do begin
    EditName.Text := Name;
    ColorButton1.ButtonColor := Color;
    EditDown.Text := IntToStr(Keys.Down);
    EditUp.Text := IntToStr(Keys.Up);
    EditLeft.Text := IntToStr(Keys.Left);
    EditRight.Text := IntToStr(Keys.Right);
    EditShoot.Text := IntToStr(Keys.Shoot);
  end;
end;

procedure TNewGameForm.ReloadList;
begin
  ListView1.Items.Count := Players.Count;
  ListView1.Refresh;
end;

procedure TNewGameForm.LoadData(Engine: TEngine);
begin
  Players.Assign(Engine.PlayerPool);
end;

procedure TNewGameForm.SaveData(Engine: TEngine);
begin
  Engine.PlayerPool.Assign(Players);
end;

procedure TNewGameForm.ColorButton1ColorChanged(Sender: TObject);
begin
  if Assigned(ListView1.Selected) then
  with TPlayer(ListView1.Selected.Data) do begin
    Color := ColorButton1.ButtonColor;
    ReloadList;
  end;
end;

procedure TNewGameForm.EditDownChange(Sender: TObject);
var
  Value: Integer;
begin
  if Assigned(ListView1.Selected) then
  with TPlayer(ListView1.Selected.Data) do begin
    if TryStrToInt(EditDown.Text, Value) then Keys.Down := Value;
    ReloadList;
  end;
end;

procedure TNewGameForm.EditDownKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  EditDown.Text := IntToStr(Key);
end;

procedure TNewGameForm.EditLeftChange(Sender: TObject);
var
  Value: Integer;
begin
  if Assigned(ListView1.Selected) then
  with TPlayer(ListView1.Selected.Data) do begin
    if TryStrToInt(EditLeft.Text, Value) then Keys.Left := Value;
    ReloadList;
  end;
end;

procedure TNewGameForm.EditLeftKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  EditLeft.Text := IntToStr(Key);
end;

procedure TNewGameForm.EditNameChange(Sender: TObject);
begin
  if Assigned(ListView1.Selected) then
  with TPlayer(ListView1.Selected.Data) do begin
    Name := EditName.Text;
    ReloadList;
  end;
end;

procedure TNewGameForm.EditRightChange(Sender: TObject);
var
  Value: Integer;
begin
  if Assigned(ListView1.Selected) then
  with TPlayer(ListView1.Selected.Data) do begin
    if TryStrToInt(EditRight.Text, Value) then Keys.Right := Value;
    ReloadList;
  end;
end;

procedure TNewGameForm.EditRightKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  EditRight.Text := IntToStr(Key);
end;

procedure TNewGameForm.EditShootChange(Sender: TObject);
var
  Value: Integer;
begin
  if Assigned(ListView1.Selected) then
  with TPlayer(ListView1.Selected.Data) do begin
    if TryStrToInt(EditShoot.Text, Value) then Keys.Shoot := Value;
    ReloadList;
  end;
end;

procedure TNewGameForm.EditShootKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  EditShoot.Text := IntToStr(Key);
end;

procedure TNewGameForm.EditUpChange(Sender: TObject);
var
  Value: Integer;
begin
  if Assigned(ListView1.Selected) then
  with TPlayer(ListView1.Selected.Data) do begin
    if TryStrToInt(EditUp.Text, Value) then Keys.Up := Value;
    ReloadList;
  end;
end;

procedure TNewGameForm.EditUpKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  EditUp.Text := IntToStr(Key);
end;

procedure TNewGameForm.FormCreate(Sender: TObject);
begin
  Players := TPlayers.Create
end;

procedure TNewGameForm.FormDestroy(Sender: TObject);
begin
  FreeAndNil(Players);
end;

procedure TNewGameForm.FormShow(Sender: TObject);
begin
  ReloadList;
end;

end.

